==> Hyper-MPI_1.1.1_aarch64_CentOS8.2_GCC8.3.1_MLNX-OFED5.4.tar.gz: Hyper-MPI_1.1.1_aarch64_CentOS8.2_GCC8.3.1_MLNX-OFED5.4/ompi/include/openmpi/opal/version.h <==
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
 * Copyright (c) 2016      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 *
 * This file should be included by any file that needs full
 * version information for the OPAL project
 */

#ifndef OPAL_VERSIONS_H
#define OPAL_VERSIONS_H

#define OPAL_MAJOR_VERSION 4
#define OPAL_MINOR_VERSION 1
#define OPAL_RELEASE_VERSION 1
#define OPAL_GREEK_VERSION "rc4"
#define OPAL_WANT_REPO_REV @OPAL_WANT_REPO_REV@
#define OPAL_REPO_REV "v4.1.1-5-g59bbbee2b2"
#ifdef OPAL_VERSION
/* If we included version.h, we want the real version, not the
   stripped (no-r number) verstion */
#undef OPAL_VERSION
#endif
#define OPAL_VERSION "4.1.1rc4"
#define OPAL_CONFIGURE_CLI " \'--prefix=/usr1/workspace/HMPI_hmpi_Compile_CentOS8.2_gcc8.3.1_MLNX5.4_aarch64/hmpi/build/../bin\' \'--disable-picky\' \'--with-platform=contrib/platform/mellanox/optimized\' \'--enable-mpi1-compatibility\' \'--with-ucx=/usr1/workspace/HMPI_hmpi_Compile_CentOS8.2_gcc8.3.1_MLNX5.4_aarch64/hmpi/build/../3rdparty/ucx/\' \'--with-pic\' \'CFLAGS=-fstack-protector-strong -fPIE -pie\' \'CXXFLAGS=-fstack-protector-strong -fPIE -pie\' \'LDFLAGS=-Wl,-z,relro,-z,now,-z,noexecstack,-s\'"

#endif

==> Hyper-MPI_1.3.0_aarch64_CentOS8.2_GCC8.3.1_MLNX-OFED5.4.tar.gz: Hyper-MPI_1.3.0_aarch64_CentOS8.2_GCC8.3.1_MLNX-OFED5.4/ompi/include/openmpi/opal/version.h <==
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
 * Copyright (c) 2016      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 *
 * This file should be included by any file that needs full
 * version information for the OPAL project
 */

#ifndef OPAL_VERSIONS_H
#define OPAL_VERSIONS_H

#define OPAL_MAJOR_VERSION 4
#define OPAL_MINOR_VERSION 1
#define OPAL_RELEASE_VERSION 1
#define OPAL_GREEK_VERSION "rc4"
#define OPAL_WANT_REPO_REV @OPAL_WANT_REPO_REV@
#define OPAL_REPO_REV "v1.3.0.spc001-huawei"
#ifdef OPAL_VERSION
/* If we included version.h, we want the real version, not the
   stripped (no-r number) verstion */
#undef OPAL_VERSION
#endif
#define OPAL_VERSION "4.1.1rc4"
#define OPAL_CONFIGURE_CLI " \'--prefix=/opt/agent_1704785671799/workspace/j_uasfXUz1/hmpi/build/../bin\' \'--disable-picky\' \'--with-platform=contrib/platform/mellanox/optimized\' \'--enable-mpi1-compatibility\' \'--with-ucx=/opt/agent_1704785671799/workspace/j_uasfXUz1/hmpi/build/../3rdparty/ucx/\' \'--with-ucg=/opt/agent_1704785671799/workspace/j_uasfXUz1/hmpi/build/../3rdparty/ucg/\' \'--with-pic\' \'CFLAGS=-fstack-protector-strong -fPIE -pie\' \'CXXFLAGS=-fstack-protector-strong -fPIE -pie\' \'LDFLAGS=-Wl,-z,relro,-z,now,-z,noexecstack,-s\'"

#endif
